/**
 * This is a helper function that is added to the dictionary object that
 * is passed to formats and actions. It will resolve a reference giving
 * you access to the token (not just the value) that a value references.
 * This allows formats to have variable references in the output. For example:
 *
 * ```css
 * --color-background-base: var(--color-core-white);
 * ```
 * @typedef {import('../../../types/Config.d.ts').RegexOptions} RegexOptions
 * @typedef {import('../../StyleDictionary.js').default} Dictionary
 * @typedef {import('../../../types/DesignToken.d.ts').TransformedTokens} Tokens
 * @typedef {import('../../../types/DesignToken.d.ts').TransformedToken} Token
 *
 * @memberof Dictionary
 * @param {string|Object<string, string|any>} value the value that contains a reference
 * @param {Tokens} tokens the dictionary to search in
 * @param {RegexOptions & { unfilteredTokens?: Tokens }} [opts]
 * @param {Token[]} [references] array of token's references because a token's value can contain multiple references due to string interpolation
 * @returns {Token[]}
 */
export default function getReferences(value: string | {
    [x: string]: string | any;
}, tokens: Tokens, opts?: (import("../../../types/Config.d.ts").RegexOptions & {
    unfilteredTokens?: import("../../../types/DesignToken.d.ts").TransformedTokens | undefined;
}) | undefined, references?: import("../../../types/DesignToken.d.ts").TransformedToken[] | undefined): Token[];
/**
 * This is a helper function that is added to the dictionary object that
 * is passed to formats and actions. It will resolve a reference giving
 * you access to the token (not just the value) that a value references.
 * This allows formats to have variable references in the output. For example:
 *
 * ```css
 * --color-background-base: var(--color-core-white);
 * ```
 */
export type RegexOptions = import('../../../types/Config.d.ts').RegexOptions;
/**
 * This is a helper function that is added to the dictionary object that
 * is passed to formats and actions. It will resolve a reference giving
 * you access to the token (not just the value) that a value references.
 * This allows formats to have variable references in the output. For example:
 *
 * ```css
 * --color-background-base: var(--color-core-white);
 * ```
 */
export type Dictionary = import('../../StyleDictionary.js').default;
/**
 * This is a helper function that is added to the dictionary object that
 * is passed to formats and actions. It will resolve a reference giving
 * you access to the token (not just the value) that a value references.
 * This allows formats to have variable references in the output. For example:
 *
 * ```css
 * --color-background-base: var(--color-core-white);
 * ```
 */
export type Tokens = import('../../../types/DesignToken.d.ts').TransformedTokens;
/**
 * This is a helper function that is added to the dictionary object that
 * is passed to formats and actions. It will resolve a reference giving
 * you access to the token (not just the value) that a value references.
 * This allows formats to have variable references in the output. For example:
 *
 * ```css
 * --color-background-base: var(--color-core-white);
 * ```
 */
export type Token = import('../../../types/DesignToken.d.ts').TransformedToken;
